AgentService

Struct AgentService 

pub struct AgentService { /* private fields */ }
Implements a client for the Gemini Enterprise for Customer Experience API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
   project_id: &str,
   location_id: &str,
   app_id: &str,
) -> anyhow::Result<()> {
    let client = AgentService::builder().build().await?;
    let mut list = client.list_agents()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}

Service Description

The service that manages agent-related resources in Gemini Enterprise for Customer Engagement (CES).

Configuration

To configure AgentService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

Pooling and Cloning

AgentService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap AgentService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl AgentService

pub fn builder() -> ClientBuilder

Returns a builder for AgentService.

let client = AgentService::builder().build().await?;
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Self
where T: AgentService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn list_apps(&self) -> ListApps

Lists apps in the given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str
) -> Result<()> {
    let mut list = client.list_apps()
        .set_parent(format!("projects/{project_id}/locations/{location_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_app(&self) -> GetApp

Gets details of the specified app.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let response = client.get_app()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_app(&self) -> CreateApp

Creates a new app in the given project and location.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_ces_v1::model::App;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str
) -> Result<()> {
    let response = client.create_app()
        .set_parent(format!("projects/{project_id}/locations/{location_id}"))
        .set_app_id("app_id_value")
        .set_app(
            App::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_app(&self) -> UpdateApp

Updates the specified app.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_ces_v1::model::App;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let response = client.update_app()
        .set_app(
            App::new().set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_app(&self) -> DeleteApp

Deletes the specified app.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    client.delete_app()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .poller().until_done().await?;
    Ok(())
}
pub fn export_app(&self) -> ExportApp

Exports the specified app.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService
) -> Result<()> {
    let response = client.export_app()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn import_app(&self) -> ImportApp

Imports the specified app.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService
) -> Result<()> {
    let response = client.import_app()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_agents(&self) -> ListAgents

Lists agents in the given app.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let mut list = client.list_agents()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_agent(&self) -> GetAgent

Gets details of the specified agent.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, agent_id: &str
) -> Result<()> {
    let response = client.get_agent()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/agents/{agent_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_agent(&self) -> CreateAgent

Creates a new agent in the given app.

Example
use google_cloud_ces_v1::model::Agent;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let response = client.create_agent()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .set_agent_id("agent_id_value")
        .set_agent(
            Agent::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_agent(&self) -> UpdateAgent

Updates the specified agent.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_ces_v1::model::Agent;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, agent_id: &str
) -> Result<()> {
    let response = client.update_agent()
        .set_agent(
            Agent::new().set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/agents/{agent_id}"))/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_agent(&self) -> DeleteAgent

Deletes the specified agent.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, agent_id: &str
) -> Result<()> {
    client.delete_agent()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/agents/{agent_id}"))
        .send().await?;
    Ok(())
}
pub fn list_examples(&self) -> ListExamples

Lists examples in the given app.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let mut list = client.list_examples()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_example(&self) -> GetExample

Gets details of the specified example.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, example_id: &str
) -> Result<()> {
    let response = client.get_example()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/examples/{example_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_example(&self) -> CreateExample

Creates a new example in the given app.

Example
use google_cloud_ces_v1::model::Example;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let response = client.create_example()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .set_example_id("example_id_value")
        .set_example(
            Example::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_example(&self) -> UpdateExample

Updates the specified example.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_ces_v1::model::Example;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, example_id: &str
) -> Result<()> {
    let response = client.update_example()
        .set_example(
            Example::new().set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/examples/{example_id}"))/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_example(&self) -> DeleteExample

Deletes the specified example.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, example_id: &str
) -> Result<()> {
    client.delete_example()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/examples/{example_id}"))
        .send().await?;
    Ok(())
}
pub fn list_tools(&self) -> ListTools

Lists tools in the given app.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let mut list = client.list_tools()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_tool(&self) -> GetTool

Gets details of the specified tool.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, tool_id: &str
) -> Result<()> {
    let response = client.get_tool()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/tools/{tool_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_conversations(&self) -> ListConversations

Lists conversations in the given app.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let mut list = client.list_conversations()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_conversation(&self) -> GetConversation

Gets details of the specified conversation.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, conversation_id: &str
) -> Result<()> {
    let response = client.get_conversation()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/conversations/{conversation_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_conversation(&self) -> DeleteConversation

Deletes the specified conversation.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, conversation_id: &str
) -> Result<()> {
    client.delete_conversation()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/conversations/{conversation_id}"))
        .send().await?;
    Ok(())
}
pub fn batch_delete_conversations(&self) -> BatchDeleteConversations

Batch deletes the specified conversations.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService
) -> Result<()> {
    let response = client.batch_delete_conversations()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_tool(&self) -> CreateTool

Creates a new tool in the given app.

Example
use google_cloud_ces_v1::model::Tool;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let response = client.create_tool()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .set_tool_id("tool_id_value")
        .set_tool(
            Tool::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_tool(&self) -> UpdateTool

Updates the specified tool.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_ces_v1::model::Tool;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, tool_id: &str
) -> Result<()> {
    let response = client.update_tool()
        .set_tool(
            Tool::new().set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/tools/{tool_id}"))/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_tool(&self) -> DeleteTool

Deletes the specified tool.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, tool_id: &str
) -> Result<()> {
    client.delete_tool()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/tools/{tool_id}"))
        .send().await?;
    Ok(())
}
pub fn list_guardrails(&self) -> ListGuardrails

Lists guardrails in the given app.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let mut list = client.list_guardrails()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_guardrail(&self) -> GetGuardrail

Gets details of the specified guardrail.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, guardrail_id: &str
) -> Result<()> {
    let response = client.get_guardrail()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/guardrails/{guardrail_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_guardrail(&self) -> CreateGuardrail

Creates a new guardrail in the given app.

Example
use google_cloud_ces_v1::model::Guardrail;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let response = client.create_guardrail()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .set_guardrail_id("guardrail_id_value")
        .set_guardrail(
            Guardrail::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_guardrail(&self) -> UpdateGuardrail

Updates the specified guardrail.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_ces_v1::model::Guardrail;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, guardrail_id: &str
) -> Result<()> {
    let response = client.update_guardrail()
        .set_guardrail(
            Guardrail::new().set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/guardrails/{guardrail_id}"))/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_guardrail(&self) -> DeleteGuardrail

Deletes the specified guardrail.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, guardrail_id: &str
) -> Result<()> {
    client.delete_guardrail()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/guardrails/{guardrail_id}"))
        .send().await?;
    Ok(())
}
pub fn list_deployments(&self) -> ListDeployments

Lists deployments in the given app.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let mut list = client.list_deployments()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_deployment(&self) -> GetDeployment

Gets details of the specified deployment.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, deployment_id: &str
) -> Result<()> {
    let response = client.get_deployment()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/deployments/{deployment_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_deployment(&self) -> CreateDeployment

Creates a new deployment in the given app.

Example
use google_cloud_ces_v1::model::Deployment;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let response = client.create_deployment()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .set_deployment_id("deployment_id_value")
        .set_deployment(
            Deployment::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_deployment(&self) -> UpdateDeployment

Updates the specified deployment.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_ces_v1::model::Deployment;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, deployment_id: &str
) -> Result<()> {
    let response = client.update_deployment()
        .set_deployment(
            Deployment::new().set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/deployments/{deployment_id}"))/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_deployment(&self) -> DeleteDeployment

Deletes the specified deployment.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, deployment_id: &str
) -> Result<()> {
    client.delete_deployment()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/deployments/{deployment_id}"))
        .send().await?;
    Ok(())
}
pub fn list_toolsets(&self) -> ListToolsets

Lists toolsets in the given app.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let mut list = client.list_toolsets()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_toolset(&self) -> GetToolset

Gets details of the specified toolset.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, toolset_id: &str
) -> Result<()> {
    let response = client.get_toolset()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/toolsets/{toolset_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_toolset(&self) -> CreateToolset

Creates a new toolset in the given app.

Example
use google_cloud_ces_v1::model::Toolset;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let response = client.create_toolset()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .set_toolset_id("toolset_id_value")
        .set_toolset(
            Toolset::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_toolset(&self) -> UpdateToolset

Updates the specified toolset.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_ces_v1::model::Toolset;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, toolset_id: &str
) -> Result<()> {
    let response = client.update_toolset()
        .set_toolset(
            Toolset::new().set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/toolsets/{toolset_id}"))/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_toolset(&self) -> DeleteToolset

Deletes the specified toolset.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, toolset_id: &str
) -> Result<()> {
    client.delete_toolset()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/toolsets/{toolset_id}"))
        .send().await?;
    Ok(())
}
pub fn list_app_versions(&self) -> ListAppVersions

Lists all app versions in the given app.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let mut list = client.list_app_versions()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_app_version(&self) -> GetAppVersion

Gets details of the specified app version.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, version_id: &str
) -> Result<()> {
    let response = client.get_app_version()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/versions/{version_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_app_version(&self) -> CreateAppVersion

Creates a new app version in the given app.

Example
use google_cloud_ces_v1::model::AppVersion;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let response = client.create_app_version()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .set_app_version(
            AppVersion::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_app_version(&self) -> DeleteAppVersion

Deletes the specified app version.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, version_id: &str
) -> Result<()> {
    client.delete_app_version()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/versions/{version_id}"))
        .send().await?;
    Ok(())
}
pub fn restore_app_version(&self) -> RestoreAppVersion

Restores the specified app version. This will create a new app version from the current draft app and overwrite the current draft with the specified app version.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService
) -> Result<()> {
    let response = client.restore_app_version()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_changelogs(&self) -> ListChangelogs

Lists the changelogs of the specified app.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str
) -> Result<()> {
    let mut list = client.list_changelogs()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_changelog(&self) -> GetChangelog

Gets the specified changelog.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService, project_id: &str, location_id: &str, app_id: &str, changelog_id: &str
) -> Result<()> {
    let response = client.get_changelog()
        .set_name(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/changelogs/{changelog_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service.

This method lists locations based on the resource scope provided in the ListLocationsRequest.name field: * Global locations: If name is empty, the method lists the public locations available to all projects. * Project-specific locations: If name follows the format projects/{project}, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project.

For gRPC and client library implementations, the resource name is passed as the name field. For direct service calls, the resource name is incorporated into the request path based on the specific service implementation and version.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_ces_v1::Result;
async fn sample(
   client: &AgentService
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}