pub struct ToolService { /* private fields */ }Expand description
Implements a client for the Gemini Enterprise for Customer Experience API.
Example
async fn sample(
) -> anyhow::Result<()> {
let client = ToolService::builder().build().await?;
let response = client.execute_tool()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Service Description
Tool service provides APIs for interacting with CES tools.
Configuration
To configure ToolService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://ces.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
ToolService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap ToolService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl ToolService
impl ToolService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for ToolService.
let client = ToolService::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: ToolService + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: ToolService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn execute_tool(&self) -> ExecuteTool
pub fn execute_tool(&self) -> ExecuteTool
Executes the given tool with the given arguments.
Example
use google_cloud_ces_v1::Result;
async fn sample(
client: &ToolService
) -> Result<()> {
let response = client.execute_tool()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn retrieve_tool_schema(&self) -> RetrieveToolSchema
pub fn retrieve_tool_schema(&self) -> RetrieveToolSchema
Retrieve the schema of the given tool. The schema is computed on the fly for the given instance of the tool.
Example
use google_cloud_ces_v1::Result;
async fn sample(
client: &ToolService
) -> Result<()> {
let response = client.retrieve_tool_schema()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn retrieve_tools(&self) -> RetrieveTools
pub fn retrieve_tools(&self) -> RetrieveTools
Retrieve the list of tools included in the specified toolset.
Example
use google_cloud_ces_v1::Result;
async fn sample(
client: &ToolService
) -> Result<()> {
let response = client.retrieve_tools()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
This method lists locations based on the resource scope provided in the [ListLocationsRequest.name] field:
- Global locations: If
nameis empty, the method lists the public locations available to all projects. * Project-specific locations: Ifnamefollows the formatprojects/{project}, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project.
For gRPC and client library implementations, the resource name is
passed as the name field. For direct service calls, the resource
name is
incorporated into the request path based on the specific service
implementation and version.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
client: &ToolService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_ces_v1::Result;
async fn sample(
client: &ToolService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
client: &ToolService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_ces_v1::Result;
async fn sample(
client: &ToolService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_ces_v1::Result;
async fn sample(
client: &ToolService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_ces_v1::Result;
async fn sample(
client: &ToolService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for ToolService
impl Clone for ToolService
Sourcefn clone(&self) -> ToolService
fn clone(&self) -> ToolService
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more