pub struct WidgetService { /* private fields */ }Expand description
Implements a client for the Gemini Enterprise for Customer Experience API.
Example
async fn sample(
) -> anyhow::Result<()> {
let client = WidgetService::builder().build().await?;
let response = client.generate_chat_token()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Service Description
Provides APIs for widgets to interact with CES APIs.
Configuration
To configure WidgetService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://ces.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
WidgetService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap WidgetService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl WidgetService
impl WidgetService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for WidgetService.
let client = WidgetService::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: WidgetService + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: WidgetService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn generate_chat_token(&self) -> GenerateChatToken
pub fn generate_chat_token(&self) -> GenerateChatToken
Generates a session scoped token for chat widget to authenticate with Session APIs.
Example
use google_cloud_ces_v1::Result;
async fn sample(
client: &WidgetService
) -> Result<()> {
let response = client.generate_chat_token()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
This method lists locations based on the resource scope provided in
the ListLocationsRequest.name field: *
Global locations: If name is empty, the method lists the
public locations available to all projects. * Project-specific
locations: If name follows the format
projects/{project}, the method lists locations visible to that
specific project. This includes public, private, or other
project-specific locations enabled for the project.
For gRPC and client library implementations, the resource name is
passed as the name field. For direct service calls, the resource
name is
incorporated into the request path based on the specific service
implementation and version.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
client: &WidgetService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_ces_v1::Result;
async fn sample(
client: &WidgetService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_ces_v1::Result;
async fn sample(
client: &WidgetService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_ces_v1::Result;
async fn sample(
client: &WidgetService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_ces_v1::Result;
async fn sample(
client: &WidgetService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_ces_v1::Result;
async fn sample(
client: &WidgetService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for WidgetService
impl Clone for WidgetService
Sourcefn clone(&self) -> WidgetService
fn clone(&self) -> WidgetService
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for WidgetService
impl !UnwindSafe for WidgetService
impl Freeze for WidgetService
impl Send for WidgetService
impl Sync for WidgetService
impl Unpin for WidgetService
impl UnsafeUnpin for WidgetService