#[non_exhaustive]pub struct RemoteDialogflowQueryParameters {
pub webhook_headers: HashMap<String, String>,
pub payload: Option<Struct>,
pub end_user_metadata: Option<Struct>,
/* private fields */
}Expand description
QueryParameters to send to the remote Dialogflow agent when the session control is transferred to the remote agent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.webhook_headers: HashMap<String, String>Optional. The HTTP headers to be sent as webhook_headers in QueryParameters.
payload: Option<Struct>Optional. The payload to be sent in QueryParameters.
end_user_metadata: Option<Struct>Optional. The end user metadata to be sent in QueryParameters.
Implementations
Sourceimpl RemoteDialogflowQueryParameters
impl RemoteDialogflowQueryParameters
Sourcepub fn set_webhook_headers<T, K, V>(self, v: T) -> Self
pub fn set_webhook_headers<T, K, V>(self, v: T) -> Self
Sets the value of webhook_headers.
Example
ⓘ
let x = RemoteDialogflowQueryParameters::new().set_webhook_headers([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_payload<T>(self, v: T) -> Self
pub fn set_payload<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_payload<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_payload<T>(self, v: Option<T>) -> Self
Sourcepub fn set_end_user_metadata<T>(self, v: T) -> Self
pub fn set_end_user_metadata<T>(self, v: T) -> Self
Sets the value of end_user_metadata.
Example
ⓘ
use wkt::Struct;
let x = RemoteDialogflowQueryParameters::new().set_end_user_metadata(Struct::default()/* use setters */);Sourcepub fn set_or_clear_end_user_metadata<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_user_metadata<T>(self, v: Option<T>) -> Self
Sets or clears the value of end_user_metadata.
Example
ⓘ
use wkt::Struct;
let x = RemoteDialogflowQueryParameters::new().set_or_clear_end_user_metadata(Some(Struct::default()/* use setters */));
let x = RemoteDialogflowQueryParameters::new().set_or_clear_end_user_metadata(None::<Struct>);Trait Implementations
Sourceimpl Clone for RemoteDialogflowQueryParameters
impl Clone for RemoteDialogflowQueryParameters
Sourcefn clone(&self) -> RemoteDialogflowQueryParameters
fn clone(&self) -> RemoteDialogflowQueryParameters
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for RemoteDialogflowQueryParameters
impl Default for RemoteDialogflowQueryParameters
Sourcefn default() -> RemoteDialogflowQueryParameters
fn default() -> RemoteDialogflowQueryParameters
Returns the “default value” for a type. Read more
impl StructuralPartialEq for RemoteDialogflowQueryParameters