#[non_exhaustive]pub struct Deployment {
pub name: String,
pub display_name: String,
pub app_version: String,
pub channel_profile: Option<ChannelProfile>,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub etag: String,
pub experiment_config: Option<ExperimentConfig>,
pub whatsapp_credentials: Option<WhatsAppCredentials>,
pub instagram_credentials: Option<InstagramCredentials>,
/* private fields */
}Expand description
A deployment represents an immutable, queryable version of the app. It is used to deploy an app version with a specific channel profile.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the deployment.
Format:
projects/{project}/locations/{location}/apps/{app}/deployments/{deployment}
display_name: StringRequired. Display name of the deployment.
app_version: StringOptional. The resource name of the app version to deploy.
Format:
projects/{project}/locations/{location}/apps/{app}/versions/{version}
Use projects/{project}/locations/{location}/apps/{app}/versions/- to use
the draft app.
channel_profile: Option<ChannelProfile>Required. The channel profile used in the deployment.
create_time: Option<Timestamp>Output only. Timestamp when this deployment was created.
update_time: Option<Timestamp>Output only. Timestamp when this deployment was last updated.
etag: StringOutput only. Etag used to ensure the object hasn’t changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.
experiment_config: Option<ExperimentConfig>Optional. Experiment configuration for the deployment.
whatsapp_credentials: Option<WhatsAppCredentials>Optional. Input only. Ephemeral WhatsApp credentials required when configuring a WhatsApp channel profile.
instagram_credentials: Option<InstagramCredentials>Optional. Input only. Ephemeral Instagram credentials required when configuring a Instagram channel profile.
Implementations
Sourceimpl Deployment
impl Deployment
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_app_version<T: Into<String>>(self, v: T) -> Self
pub fn set_app_version<T: Into<String>>(self, v: T) -> Self
Sets the value of app_version.
Example
let x = Deployment::new().set_app_version(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/versions/{version_id}"));Sourcepub fn set_channel_profile<T>(self, v: T) -> Selfwhere
T: Into<ChannelProfile>,
pub fn set_channel_profile<T>(self, v: T) -> Selfwhere
T: Into<ChannelProfile>,
Sets the value of channel_profile.
Example
use google_cloud_ces_v1::model::ChannelProfile;
let x = Deployment::new().set_channel_profile(ChannelProfile::default()/* use setters */);Sourcepub fn set_or_clear_channel_profile<T>(self, v: Option<T>) -> Selfwhere
T: Into<ChannelProfile>,
pub fn set_or_clear_channel_profile<T>(self, v: Option<T>) -> Selfwhere
T: Into<ChannelProfile>,
Sets or clears the value of channel_profile.
Example
use google_cloud_ces_v1::model::ChannelProfile;
let x = Deployment::new().set_or_clear_channel_profile(Some(ChannelProfile::default()/* use setters */));
let x = Deployment::new().set_or_clear_channel_profile(None::<ChannelProfile>);Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Deployment::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Deployment::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Deployment::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Deployment::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Deployment::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Deployment::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_experiment_config<T>(self, v: T) -> Selfwhere
T: Into<ExperimentConfig>,
pub fn set_experiment_config<T>(self, v: T) -> Selfwhere
T: Into<ExperimentConfig>,
Sets the value of experiment_config.
Example
use google_cloud_ces_v1::model::ExperimentConfig;
let x = Deployment::new().set_experiment_config(ExperimentConfig::default()/* use setters */);Sourcepub fn set_or_clear_experiment_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExperimentConfig>,
pub fn set_or_clear_experiment_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExperimentConfig>,
Sets or clears the value of experiment_config.
Example
use google_cloud_ces_v1::model::ExperimentConfig;
let x = Deployment::new().set_or_clear_experiment_config(Some(ExperimentConfig::default()/* use setters */));
let x = Deployment::new().set_or_clear_experiment_config(None::<ExperimentConfig>);Sourcepub fn set_whatsapp_credentials<T>(self, v: T) -> Selfwhere
T: Into<WhatsAppCredentials>,
pub fn set_whatsapp_credentials<T>(self, v: T) -> Selfwhere
T: Into<WhatsAppCredentials>,
Sets the value of whatsapp_credentials.
Example
use google_cloud_ces_v1::model::WhatsAppCredentials;
let x = Deployment::new().set_whatsapp_credentials(WhatsAppCredentials::default()/* use setters */);Sourcepub fn set_or_clear_whatsapp_credentials<T>(self, v: Option<T>) -> Selfwhere
T: Into<WhatsAppCredentials>,
pub fn set_or_clear_whatsapp_credentials<T>(self, v: Option<T>) -> Selfwhere
T: Into<WhatsAppCredentials>,
Sets or clears the value of whatsapp_credentials.
Example
use google_cloud_ces_v1::model::WhatsAppCredentials;
let x = Deployment::new().set_or_clear_whatsapp_credentials(Some(WhatsAppCredentials::default()/* use setters */));
let x = Deployment::new().set_or_clear_whatsapp_credentials(None::<WhatsAppCredentials>);Sourcepub fn set_instagram_credentials<T>(self, v: T) -> Selfwhere
T: Into<InstagramCredentials>,
pub fn set_instagram_credentials<T>(self, v: T) -> Selfwhere
T: Into<InstagramCredentials>,
Sets the value of instagram_credentials.
Example
use google_cloud_ces_v1::model::InstagramCredentials;
let x = Deployment::new().set_instagram_credentials(InstagramCredentials::default()/* use setters */);Sourcepub fn set_or_clear_instagram_credentials<T>(self, v: Option<T>) -> Selfwhere
T: Into<InstagramCredentials>,
pub fn set_or_clear_instagram_credentials<T>(self, v: Option<T>) -> Selfwhere
T: Into<InstagramCredentials>,
Sets or clears the value of instagram_credentials.
Example
use google_cloud_ces_v1::model::InstagramCredentials;
let x = Deployment::new().set_or_clear_instagram_credentials(Some(InstagramCredentials::default()/* use setters */));
let x = Deployment::new().set_or_clear_instagram_credentials(None::<InstagramCredentials>);Trait Implementations
Sourceimpl Clone for Deployment
impl Clone for Deployment
Sourcefn clone(&self) -> Deployment
fn clone(&self) -> Deployment
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for Deployment
impl Debug for Deployment
Sourceimpl Default for Deployment
impl Default for Deployment
Sourcefn default() -> Deployment
fn default() -> Deployment
Sourceimpl PartialEq for Deployment
impl PartialEq for Deployment
impl StructuralPartialEq for Deployment