#[non_exhaustive]pub struct GenerateChatTokenRequest {
pub name: String,
pub deployment: String,
pub recaptcha_token: String,
pub live_handoff_enabled: bool,
/* private fields */
}Expand description
Request message for WidgetService.GenerateChatToken.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The session name to generate the chat token for. Format: projects/{project}/locations/{location}/apps/{app}/sessions/{session}
deployment: StringRequired. The deployment of the app to use for the session. Format: projects/{project}/locations/{location}/apps/{app}/deployments/{deployment}
recaptcha_token: StringOptional. The reCAPTCHA token generated by the client-side chat widget.
live_handoff_enabled: boolOptional. Indicates if live handoff is enabled for the session.
Implementations
Sourceimpl GenerateChatTokenRequest
impl GenerateChatTokenRequest
Sourcepub fn set_deployment<T: Into<String>>(self, v: T) -> Self
pub fn set_deployment<T: Into<String>>(self, v: T) -> Self
Sets the value of deployment.
Example
ⓘ
let x = GenerateChatTokenRequest::new().set_deployment(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/deployments/{deployment_id}"));Sourcepub fn set_recaptcha_token<T: Into<String>>(self, v: T) -> Self
pub fn set_recaptcha_token<T: Into<String>>(self, v: T) -> Self
Sets the value of recaptcha_token.
Example
ⓘ
let x = GenerateChatTokenRequest::new().set_recaptcha_token("example");Sourcepub fn set_live_handoff_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_live_handoff_enabled<T: Into<bool>>(self, v: T) -> Self
Sets the value of live_handoff_enabled.
Example
ⓘ
let x = GenerateChatTokenRequest::new().set_live_handoff_enabled(true);Trait Implementations
Sourceimpl Clone for GenerateChatTokenRequest
impl Clone for GenerateChatTokenRequest
Sourcefn clone(&self) -> GenerateChatTokenRequest
fn clone(&self) -> GenerateChatTokenRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GenerateChatTokenRequest
impl Debug for GenerateChatTokenRequest
Sourceimpl Default for GenerateChatTokenRequest
impl Default for GenerateChatTokenRequest
Sourcefn default() -> GenerateChatTokenRequest
fn default() -> GenerateChatTokenRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for GenerateChatTokenRequest
impl Message for GenerateChatTokenRequest
Sourceimpl PartialEq for GenerateChatTokenRequest
impl PartialEq for GenerateChatTokenRequest
impl StructuralPartialEq for GenerateChatTokenRequest