SessionConfig

Struct SessionConfig 

#[non_exhaustive]
pub struct SessionConfig { pub session: String, pub input_audio_config: Option<InputAudioConfig>, pub output_audio_config: Option<OutputAudioConfig>, pub historical_contexts: Vec<Message>, pub entry_agent: String, pub deployment: String, pub time_zone: String, pub use_tool_fakes: bool, pub remote_dialogflow_query_parameters: Option<RemoteDialogflowQueryParameters>, pub enable_text_streaming: bool, /* private fields */ }
The configuration for the session.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
session: String

Required. The unique identifier of the session. Format: projects/{project}/locations/{location}/apps/{app}/sessions/{session}

input_audio_config: Option<InputAudioConfig>

Optional. Configuration for processing the input audio.

output_audio_config: Option<OutputAudioConfig>

Optional. Configuration for generating the output audio.

historical_contexts: Vec<Message>

Optional. The historical context of the session, including user inputs, agent responses, and other messages. Typically, CES agent would manage session automatically so client doesn’t need to explicitly populate this field. However, client can optionally override the historical contexts to force the session start from certain state.

entry_agent: String

Optional. The entry agent to handle the session. If not specified, the session will be handled by the root agent of the app. Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}

deployment: String

Optional. The deployment of the app to use for the session. Format: projects/{project}/locations/{location}/apps/{app}/deployments/{deployment}

time_zone: String

Optional. The time zone of the user. If provided, the agent will use the time zone for date and time related variables. Otherwise, the agent will use the time zone specified in the App.time_zone_settings.

The format is the IANA Time Zone Database time zone, e.g. “America/Los_Angeles”.

use_tool_fakes: bool

Optional. Whether to use tool fakes for the session. If this field is set, the agent will attempt use tool fakes instead of calling the real tools.

remote_dialogflow_query_parameters: Option<RemoteDialogflowQueryParameters>

Optional. QueryParameters to send to the remote Dialogflow agent when the session control is transferred to the remote agent.

enable_text_streaming: bool

Optional. Whether to enable streaming text outputs from the model. By default, text outputs from the model are collected before sending to the client. NOTE: This is only supported for text (non-voice) sessions via [StreamRunSession][google.cloud.ces.v1.SessionService.StreamRunSession] or [BidiRunSession][google.cloud.ces.v1.SessionService.BidiRunSession].

Implementations

Source

impl SessionConfig

pub fn new() -> Self

Creates a new default instance.

pub fn set_session<T: Into<String>>(self, v: T) -> Self

Sets the value of session.

Example
let x = SessionConfig::new().set_session("example");
pub fn set_input_audio_config<T>(self, v: T) -> Self

Sets the value of input_audio_config.

Example
use google_cloud_ces_v1::model::InputAudioConfig;
let x = SessionConfig::new().set_input_audio_config(InputAudioConfig::default()/* use setters */);
pub fn set_or_clear_input_audio_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of input_audio_config.

Example
use google_cloud_ces_v1::model::InputAudioConfig;
let x = SessionConfig::new().set_or_clear_input_audio_config(Some(InputAudioConfig::default()/* use setters */));
let x = SessionConfig::new().set_or_clear_input_audio_config(None::<InputAudioConfig>);
pub fn set_output_audio_config<T>(self, v: T) -> Self

Sets the value of output_audio_config.

Example
use google_cloud_ces_v1::model::OutputAudioConfig;
let x = SessionConfig::new().set_output_audio_config(OutputAudioConfig::default()/* use setters */);
pub fn set_or_clear_output_audio_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of output_audio_config.

Example
use google_cloud_ces_v1::model::OutputAudioConfig;
let x = SessionConfig::new().set_or_clear_output_audio_config(Some(OutputAudioConfig::default()/* use setters */));
let x = SessionConfig::new().set_or_clear_output_audio_config(None::<OutputAudioConfig>);
pub fn set_historical_contexts<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Message>,

Sets the value of historical_contexts.

Example
use google_cloud_ces_v1::model::Message;
let x = SessionConfig::new()
    .set_historical_contexts([
        Message::default()/* use setters */,
        Message::default()/* use (different) setters */,
    ]);
pub fn set_entry_agent<T: Into<String>>(self, v: T) -> Self

Sets the value of entry_agent.

Example
let x = SessionConfig::new().set_entry_agent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/agents/{agent_id}"));
pub fn set_deployment<T: Into<String>>(self, v: T) -> Self

Sets the value of deployment.

Example
let x = SessionConfig::new().set_deployment("example");
pub fn set_time_zone<T: Into<String>>(self, v: T) -> Self

Sets the value of time_zone.

Example
let x = SessionConfig::new().set_time_zone("example");
pub fn set_use_tool_fakes<T: Into<bool>>(self, v: T) -> Self

Sets the value of use_tool_fakes.

Example
let x = SessionConfig::new().set_use_tool_fakes(true);
pub fn set_remote_dialogflow_query_parameters<T>(self, v: T) -> Self

Sets the value of remote_dialogflow_query_parameters.

Example
use google_cloud_ces_v1::model::session_config::RemoteDialogflowQueryParameters;
let x = SessionConfig::new().set_remote_dialogflow_query_parameters(RemoteDialogflowQueryParameters::default()/* use setters */);
pub fn set_or_clear_remote_dialogflow_query_parameters<T>( self, v: Option<T>, ) -> Self

Sets or clears the value of remote_dialogflow_query_parameters.

Example
use google_cloud_ces_v1::model::session_config::RemoteDialogflowQueryParameters;
let x = SessionConfig::new().set_or_clear_remote_dialogflow_query_parameters(Some(RemoteDialogflowQueryParameters::default()/* use setters */));
let x = SessionConfig::new().set_or_clear_remote_dialogflow_query_parameters(None::<RemoteDialogflowQueryParameters>);
pub fn set_enable_text_streaming<T: Into<bool>>(self, v: T) -> Self

Sets the value of enable_text_streaming.

Example
let x = SessionConfig::new().set_enable_text_streaming(true);