SessionInput

Struct SessionInput 

#[non_exhaustive]
pub struct SessionInput { pub will_continue: bool, pub input_type: Option<InputType>, /* private fields */ }
Input for the session.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
will_continue: bool

Optional. A flag to indicate if the current message is a fragment of a larger input in the bidi streaming session.

When set to true, the agent defers processing until it receives a subsequent message where will_continue is false, or until the system detects an endpoint in the audio input.

NOTE: This field does not apply to audio and DTMF inputs, as they are always processed automatically based on the endpointing signal.

input_type: Option<InputType>

The type of the input.

Implementations

Source

impl SessionInput

pub fn new() -> Self

Creates a new default instance.

pub fn set_will_continue<T: Into<bool>>(self, v: T) -> Self

Sets the value of will_continue.

Example
let x = SessionInput::new().set_will_continue(true);
pub fn set_input_type<T: Into<Option<InputType>>>(self, v: T) -> Self

Sets the value of input_type.

Note that all the setters affecting input_type are mutually exclusive.

Example
use google_cloud_ces_v1::model::session_input::InputType;
let x = SessionInput::new().set_input_type(Some(InputType::Text("example".to_string())));
pub fn text(&self) -> Option<&String>

The value of input_type if it holds a Text, None if the field is not set or holds a different branch.

pub fn set_text<T: Into<String>>(self, v: T) -> Self

Sets the value of input_type to hold a Text.

Note that all the setters affecting input_type are mutually exclusive.

Example
let x = SessionInput::new().set_text("example");
assert!(x.text().is_some());
assert!(x.dtmf().is_none());
assert!(x.audio().is_none());
assert!(x.tool_responses().is_none());
assert!(x.image().is_none());
assert!(x.blob().is_none());
assert!(x.variables().is_none());
assert!(x.event().is_none());
pub fn dtmf(&self) -> Option<&String>

The value of input_type if it holds a Dtmf, None if the field is not set or holds a different branch.

pub fn set_dtmf<T: Into<String>>(self, v: T) -> Self

Sets the value of input_type to hold a Dtmf.

Note that all the setters affecting input_type are mutually exclusive.

Example
let x = SessionInput::new().set_dtmf("example");
assert!(x.dtmf().is_some());
assert!(x.text().is_none());
assert!(x.audio().is_none());
assert!(x.tool_responses().is_none());
assert!(x.image().is_none());
assert!(x.blob().is_none());
assert!(x.variables().is_none());
assert!(x.event().is_none());
pub fn audio(&self) -> Option<&Bytes>

The value of input_type if it holds a Audio, None if the field is not set or holds a different branch.

pub fn set_audio<T: Into<Bytes>>(self, v: T) -> Self

Sets the value of input_type to hold a Audio.

Note that all the setters affecting input_type are mutually exclusive.

Example
let x = SessionInput::new().set_audio(bytes::Bytes::from_static(b"example"));
assert!(x.audio().is_some());
assert!(x.text().is_none());
assert!(x.dtmf().is_none());
assert!(x.tool_responses().is_none());
assert!(x.image().is_none());
assert!(x.blob().is_none());
assert!(x.variables().is_none());
assert!(x.event().is_none());
pub fn tool_responses(&self) -> Option<&Box<ToolResponses>>

The value of input_type if it holds a ToolResponses, None if the field is not set or holds a different branch.

pub fn set_tool_responses<T: Into<Box<ToolResponses>>>(self, v: T) -> Self

Sets the value of input_type to hold a ToolResponses.

Note that all the setters affecting input_type are mutually exclusive.

Example
use google_cloud_ces_v1::model::ToolResponses;
let x = SessionInput::new().set_tool_responses(ToolResponses::default()/* use setters */);
assert!(x.tool_responses().is_some());
assert!(x.text().is_none());
assert!(x.dtmf().is_none());
assert!(x.audio().is_none());
assert!(x.image().is_none());
assert!(x.blob().is_none());
assert!(x.variables().is_none());
assert!(x.event().is_none());
pub fn image(&self) -> Option<&Box<Image>>

The value of input_type if it holds a Image, None if the field is not set or holds a different branch.

pub fn set_image<T: Into<Box<Image>>>(self, v: T) -> Self

Sets the value of input_type to hold a Image.

Note that all the setters affecting input_type are mutually exclusive.

Example
use google_cloud_ces_v1::model::Image;
let x = SessionInput::new().set_image(Image::default()/* use setters */);
assert!(x.image().is_some());
assert!(x.text().is_none());
assert!(x.dtmf().is_none());
assert!(x.audio().is_none());
assert!(x.tool_responses().is_none());
assert!(x.blob().is_none());
assert!(x.variables().is_none());
assert!(x.event().is_none());
pub fn blob(&self) -> Option<&Box<Blob>>

The value of input_type if it holds a Blob, None if the field is not set or holds a different branch.

pub fn set_blob<T: Into<Box<Blob>>>(self, v: T) -> Self

Sets the value of input_type to hold a Blob.

Note that all the setters affecting input_type are mutually exclusive.

Example
use google_cloud_ces_v1::model::Blob;
let x = SessionInput::new().set_blob(Blob::default()/* use setters */);
assert!(x.blob().is_some());
assert!(x.text().is_none());
assert!(x.dtmf().is_none());
assert!(x.audio().is_none());
assert!(x.tool_responses().is_none());
assert!(x.image().is_none());
assert!(x.variables().is_none());
assert!(x.event().is_none());
pub fn variables(&self) -> Option<&Box<Struct>>

The value of input_type if it holds a Variables, None if the field is not set or holds a different branch.

pub fn set_variables<T: Into<Box<Struct>>>(self, v: T) -> Self

Sets the value of input_type to hold a Variables.

Note that all the setters affecting input_type are mutually exclusive.

Example
use wkt::Struct;
let x = SessionInput::new().set_variables(Struct::default()/* use setters */);
assert!(x.variables().is_some());
assert!(x.text().is_none());
assert!(x.dtmf().is_none());
assert!(x.audio().is_none());
assert!(x.tool_responses().is_none());
assert!(x.image().is_none());
assert!(x.blob().is_none());
assert!(x.event().is_none());
pub fn event(&self) -> Option<&Box<Event>>

The value of input_type if it holds a Event, None if the field is not set or holds a different branch.

pub fn set_event<T: Into<Box<Event>>>(self, v: T) -> Self

Sets the value of input_type to hold a Event.

Note that all the setters affecting input_type are mutually exclusive.

Example
use google_cloud_ces_v1::model::Event;
let x = SessionInput::new().set_event(Event::default()/* use setters */);
assert!(x.event().is_some());
assert!(x.text().is_none());
assert!(x.dtmf().is_none());
assert!(x.audio().is_none());
assert!(x.tool_responses().is_none());
assert!(x.image().is_none());
assert!(x.blob().is_none());
assert!(x.variables().is_none());