#[non_exhaustive]pub struct App {Show 28 fields
pub name: String,
pub display_name: String,
pub description: String,
pub pinned: bool,
pub root_agent: String,
pub language_settings: Option<LanguageSettings>,
pub time_zone_settings: Option<TimeZoneSettings>,
pub audio_processing_config: Option<AudioProcessingConfig>,
pub logging_settings: Option<LoggingSettings>,
pub error_handling_settings: Option<ErrorHandlingSettings>,
pub model_settings: Option<ModelSettings>,
pub tool_execution_mode: ToolExecutionMode,
pub evaluation_metrics_thresholds: Option<EvaluationMetricsThresholds>,
pub variable_declarations: Vec<VariableDeclaration>,
pub predefined_variable_declarations: Vec<VariableDeclaration>,
pub global_instruction: String,
pub guardrails: Vec<String>,
pub data_store_settings: Option<DataStoreSettings>,
pub default_channel_profile: Option<ChannelProfile>,
pub metadata: HashMap<String, String>,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub etag: String,
pub deployment_count: i32,
pub client_certificate_settings: Option<ClientCertificateSettings>,
pub vpc_sc_settings: Option<VpcScSettings>,
pub locked: bool,
pub validation_errors: Vec<String>,
/* private fields */
}Expand description
An app serves as a top-level container for a group of agents, including the root agent and its sub-agents, along with their associated configurations. These agents work together to achieve specific goals within the app’s context.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The unique identifier of the app.
Format: projects/{project}/locations/{location}/apps/{app}
display_name: StringRequired. Display name of the app.
description: StringOptional. Human-readable description of the app.
pinned: boolOptional. Whether the app is pinned in the app list.
root_agent: StringOptional. The root agent is the entry point of the app.
Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}
language_settings: Option<LanguageSettings>Optional. Language settings of the app.
time_zone_settings: Option<TimeZoneSettings>Optional. TimeZone settings of the app.
audio_processing_config: Option<AudioProcessingConfig>Optional. Audio processing configuration of the app.
logging_settings: Option<LoggingSettings>Optional. Logging settings of the app.
error_handling_settings: Option<ErrorHandlingSettings>Optional. Error handling settings of the app.
model_settings: Option<ModelSettings>Optional. The default LLM model settings for the app. Individual resources (e.g. agents, guardrails) can override these configurations as needed.
tool_execution_mode: ToolExecutionModeOptional. The tool execution mode for the app. If not provided, will default to PARALLEL.
evaluation_metrics_thresholds: Option<EvaluationMetricsThresholds>Optional. The evaluation thresholds for the app.
variable_declarations: Vec<VariableDeclaration>Optional. The declarations of the variables.
predefined_variable_declarations: Vec<VariableDeclaration>Output only. The declarations of predefined variables for the app.
global_instruction: StringOptional. Instructions for all the agents in the app. You can use this instruction to set up a stable identity or personality across all the agents.
guardrails: Vec<String>Optional. List of guardrails for the app.
Format:
projects/{project}/locations/{location}/apps/{app}/guardrails/{guardrail}
data_store_settings: Option<DataStoreSettings>Optional. The data store settings for the app.
default_channel_profile: Option<ChannelProfile>Optional. The default channel profile used by the app.
metadata: HashMap<String, String>Optional. Metadata about the app. This field can be used to store additional information relevant to the app’s details or intended usages.
create_time: Option<Timestamp>Output only. Timestamp when the app was created.
update_time: Option<Timestamp>Output only. Timestamp when the app was last updated.
etag: StringOutput only. Etag used to ensure the object hasn’t changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.
deployment_count: i32Output only. Number of deployments in the app.
client_certificate_settings: Option<ClientCertificateSettings>Optional. The default client certificate settings for the app.
vpc_sc_settings: Option<VpcScSettings>Optional. VPC-SC settings for the app.
locked: boolOptional. Indicates whether the app is locked for changes. If the app is locked, modifications to the app resources will be rejected.
validation_errors: Vec<String>Output only. Misconfigurations or warnings in the app.
Implementations
Sourceimpl App
impl App
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_pinned<T: Into<bool>>(self, v: T) -> Self
pub fn set_pinned<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_root_agent<T: Into<String>>(self, v: T) -> Self
pub fn set_root_agent<T: Into<String>>(self, v: T) -> Self
Sets the value of root_agent.
Example
let x = App::new().set_root_agent(format!("projects/{project_id}/locations/{location_id}/apps/{app_id}/agents/{agent_id}"));Sourcepub fn set_language_settings<T>(self, v: T) -> Selfwhere
T: Into<LanguageSettings>,
pub fn set_language_settings<T>(self, v: T) -> Selfwhere
T: Into<LanguageSettings>,
Sets the value of language_settings.
Example
use google_cloud_ces_v1::model::LanguageSettings;
let x = App::new().set_language_settings(LanguageSettings::default()/* use setters */);Sourcepub fn set_or_clear_language_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<LanguageSettings>,
pub fn set_or_clear_language_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<LanguageSettings>,
Sets or clears the value of language_settings.
Example
use google_cloud_ces_v1::model::LanguageSettings;
let x = App::new().set_or_clear_language_settings(Some(LanguageSettings::default()/* use setters */));
let x = App::new().set_or_clear_language_settings(None::<LanguageSettings>);Sourcepub fn set_time_zone_settings<T>(self, v: T) -> Selfwhere
T: Into<TimeZoneSettings>,
pub fn set_time_zone_settings<T>(self, v: T) -> Selfwhere
T: Into<TimeZoneSettings>,
Sets the value of time_zone_settings.
Example
use google_cloud_ces_v1::model::TimeZoneSettings;
let x = App::new().set_time_zone_settings(TimeZoneSettings::default()/* use setters */);Sourcepub fn set_or_clear_time_zone_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<TimeZoneSettings>,
pub fn set_or_clear_time_zone_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<TimeZoneSettings>,
Sets or clears the value of time_zone_settings.
Example
use google_cloud_ces_v1::model::TimeZoneSettings;
let x = App::new().set_or_clear_time_zone_settings(Some(TimeZoneSettings::default()/* use setters */));
let x = App::new().set_or_clear_time_zone_settings(None::<TimeZoneSettings>);Sourcepub fn set_audio_processing_config<T>(self, v: T) -> Selfwhere
T: Into<AudioProcessingConfig>,
pub fn set_audio_processing_config<T>(self, v: T) -> Selfwhere
T: Into<AudioProcessingConfig>,
Sets the value of audio_processing_config.
Example
use google_cloud_ces_v1::model::AudioProcessingConfig;
let x = App::new().set_audio_processing_config(AudioProcessingConfig::default()/* use setters */);Sourcepub fn set_or_clear_audio_processing_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<AudioProcessingConfig>,
pub fn set_or_clear_audio_processing_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<AudioProcessingConfig>,
Sets or clears the value of audio_processing_config.
Example
use google_cloud_ces_v1::model::AudioProcessingConfig;
let x = App::new().set_or_clear_audio_processing_config(Some(AudioProcessingConfig::default()/* use setters */));
let x = App::new().set_or_clear_audio_processing_config(None::<AudioProcessingConfig>);Sourcepub fn set_logging_settings<T>(self, v: T) -> Selfwhere
T: Into<LoggingSettings>,
pub fn set_logging_settings<T>(self, v: T) -> Selfwhere
T: Into<LoggingSettings>,
Sets the value of logging_settings.
Example
use google_cloud_ces_v1::model::LoggingSettings;
let x = App::new().set_logging_settings(LoggingSettings::default()/* use setters */);Sourcepub fn set_or_clear_logging_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<LoggingSettings>,
pub fn set_or_clear_logging_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<LoggingSettings>,
Sets or clears the value of logging_settings.
Example
use google_cloud_ces_v1::model::LoggingSettings;
let x = App::new().set_or_clear_logging_settings(Some(LoggingSettings::default()/* use setters */));
let x = App::new().set_or_clear_logging_settings(None::<LoggingSettings>);Sourcepub fn set_error_handling_settings<T>(self, v: T) -> Selfwhere
T: Into<ErrorHandlingSettings>,
pub fn set_error_handling_settings<T>(self, v: T) -> Selfwhere
T: Into<ErrorHandlingSettings>,
Sets the value of error_handling_settings.
Example
use google_cloud_ces_v1::model::ErrorHandlingSettings;
let x = App::new().set_error_handling_settings(ErrorHandlingSettings::default()/* use setters */);Sourcepub fn set_or_clear_error_handling_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<ErrorHandlingSettings>,
pub fn set_or_clear_error_handling_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<ErrorHandlingSettings>,
Sets or clears the value of error_handling_settings.
Example
use google_cloud_ces_v1::model::ErrorHandlingSettings;
let x = App::new().set_or_clear_error_handling_settings(Some(ErrorHandlingSettings::default()/* use setters */));
let x = App::new().set_or_clear_error_handling_settings(None::<ErrorHandlingSettings>);Sourcepub fn set_model_settings<T>(self, v: T) -> Selfwhere
T: Into<ModelSettings>,
pub fn set_model_settings<T>(self, v: T) -> Selfwhere
T: Into<ModelSettings>,
Sets the value of model_settings.
Example
use google_cloud_ces_v1::model::ModelSettings;
let x = App::new().set_model_settings(ModelSettings::default()/* use setters */);Sourcepub fn set_or_clear_model_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<ModelSettings>,
pub fn set_or_clear_model_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<ModelSettings>,
Sets or clears the value of model_settings.
Example
use google_cloud_ces_v1::model::ModelSettings;
let x = App::new().set_or_clear_model_settings(Some(ModelSettings::default()/* use setters */));
let x = App::new().set_or_clear_model_settings(None::<ModelSettings>);Sourcepub fn set_tool_execution_mode<T: Into<ToolExecutionMode>>(self, v: T) -> Self
pub fn set_tool_execution_mode<T: Into<ToolExecutionMode>>(self, v: T) -> Self
Sets the value of tool_execution_mode.
Example
use google_cloud_ces_v1::model::app::ToolExecutionMode;
let x0 = App::new().set_tool_execution_mode(ToolExecutionMode::Parallel);
let x1 = App::new().set_tool_execution_mode(ToolExecutionMode::Sequential);Sourcepub fn set_evaluation_metrics_thresholds<T>(self, v: T) -> Selfwhere
T: Into<EvaluationMetricsThresholds>,
pub fn set_evaluation_metrics_thresholds<T>(self, v: T) -> Selfwhere
T: Into<EvaluationMetricsThresholds>,
Sets the value of evaluation_metrics_thresholds.
Example
use google_cloud_ces_v1::model::EvaluationMetricsThresholds;
let x = App::new().set_evaluation_metrics_thresholds(EvaluationMetricsThresholds::default()/* use setters */);Sourcepub fn set_or_clear_evaluation_metrics_thresholds<T>(self, v: Option<T>) -> Selfwhere
T: Into<EvaluationMetricsThresholds>,
pub fn set_or_clear_evaluation_metrics_thresholds<T>(self, v: Option<T>) -> Selfwhere
T: Into<EvaluationMetricsThresholds>,
Sets or clears the value of evaluation_metrics_thresholds.
Example
use google_cloud_ces_v1::model::EvaluationMetricsThresholds;
let x = App::new().set_or_clear_evaluation_metrics_thresholds(Some(EvaluationMetricsThresholds::default()/* use setters */));
let x = App::new().set_or_clear_evaluation_metrics_thresholds(None::<EvaluationMetricsThresholds>);Sourcepub fn set_variable_declarations<T, V>(self, v: T) -> Self
pub fn set_variable_declarations<T, V>(self, v: T) -> Self
Sets the value of variable_declarations.
Example
use google_cloud_ces_v1::model::app::VariableDeclaration;
let x = App::new()
.set_variable_declarations([
VariableDeclaration::default()/* use setters */,
VariableDeclaration::default()/* use (different) setters */,
]);Sourcepub fn set_predefined_variable_declarations<T, V>(self, v: T) -> Self
pub fn set_predefined_variable_declarations<T, V>(self, v: T) -> Self
Sets the value of predefined_variable_declarations.
Example
use google_cloud_ces_v1::model::app::VariableDeclaration;
let x = App::new()
.set_predefined_variable_declarations([
VariableDeclaration::default()/* use setters */,
VariableDeclaration::default()/* use (different) setters */,
]);Sourcepub fn set_global_instruction<T: Into<String>>(self, v: T) -> Self
pub fn set_global_instruction<T: Into<String>>(self, v: T) -> Self
Sets the value of global_instruction.
Example
let x = App::new().set_global_instruction("example");Sourcepub fn set_guardrails<T, V>(self, v: T) -> Self
pub fn set_guardrails<T, V>(self, v: T) -> Self
Sourcepub fn set_data_store_settings<T>(self, v: T) -> Selfwhere
T: Into<DataStoreSettings>,
pub fn set_data_store_settings<T>(self, v: T) -> Selfwhere
T: Into<DataStoreSettings>,
Sets the value of data_store_settings.
Example
use google_cloud_ces_v1::model::DataStoreSettings;
let x = App::new().set_data_store_settings(DataStoreSettings::default()/* use setters */);Sourcepub fn set_or_clear_data_store_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataStoreSettings>,
pub fn set_or_clear_data_store_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataStoreSettings>,
Sets or clears the value of data_store_settings.
Example
use google_cloud_ces_v1::model::DataStoreSettings;
let x = App::new().set_or_clear_data_store_settings(Some(DataStoreSettings::default()/* use setters */));
let x = App::new().set_or_clear_data_store_settings(None::<DataStoreSettings>);Sourcepub fn set_default_channel_profile<T>(self, v: T) -> Selfwhere
T: Into<ChannelProfile>,
pub fn set_default_channel_profile<T>(self, v: T) -> Selfwhere
T: Into<ChannelProfile>,
Sets the value of default_channel_profile.
Example
use google_cloud_ces_v1::model::ChannelProfile;
let x = App::new().set_default_channel_profile(ChannelProfile::default()/* use setters */);Sourcepub fn set_or_clear_default_channel_profile<T>(self, v: Option<T>) -> Selfwhere
T: Into<ChannelProfile>,
pub fn set_or_clear_default_channel_profile<T>(self, v: Option<T>) -> Selfwhere
T: Into<ChannelProfile>,
Sets or clears the value of default_channel_profile.
Example
use google_cloud_ces_v1::model::ChannelProfile;
let x = App::new().set_or_clear_default_channel_profile(Some(ChannelProfile::default()/* use setters */));
let x = App::new().set_or_clear_default_channel_profile(None::<ChannelProfile>);Sourcepub fn set_metadata<T, K, V>(self, v: T) -> Self
pub fn set_metadata<T, K, V>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = App::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = App::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = App::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = App::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = App::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = App::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_deployment_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_deployment_count<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_client_certificate_settings<T>(self, v: T) -> Selfwhere
T: Into<ClientCertificateSettings>,
pub fn set_client_certificate_settings<T>(self, v: T) -> Selfwhere
T: Into<ClientCertificateSettings>,
Sets the value of client_certificate_settings.
Example
use google_cloud_ces_v1::model::ClientCertificateSettings;
let x = App::new().set_client_certificate_settings(ClientCertificateSettings::default()/* use setters */);Sourcepub fn set_or_clear_client_certificate_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<ClientCertificateSettings>,
pub fn set_or_clear_client_certificate_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<ClientCertificateSettings>,
Sets or clears the value of client_certificate_settings.
Example
use google_cloud_ces_v1::model::ClientCertificateSettings;
let x = App::new().set_or_clear_client_certificate_settings(Some(ClientCertificateSettings::default()/* use setters */));
let x = App::new().set_or_clear_client_certificate_settings(None::<ClientCertificateSettings>);Sourcepub fn set_vpc_sc_settings<T>(self, v: T) -> Selfwhere
T: Into<VpcScSettings>,
pub fn set_vpc_sc_settings<T>(self, v: T) -> Selfwhere
T: Into<VpcScSettings>,
Sets the value of vpc_sc_settings.
Example
use google_cloud_ces_v1::model::VpcScSettings;
let x = App::new().set_vpc_sc_settings(VpcScSettings::default()/* use setters */);Sourcepub fn set_or_clear_vpc_sc_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<VpcScSettings>,
pub fn set_or_clear_vpc_sc_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<VpcScSettings>,
Sets or clears the value of vpc_sc_settings.
Example
use google_cloud_ces_v1::model::VpcScSettings;
let x = App::new().set_or_clear_vpc_sc_settings(Some(VpcScSettings::default()/* use setters */));
let x = App::new().set_or_clear_vpc_sc_settings(None::<VpcScSettings>);Sourcepub fn set_locked<T: Into<bool>>(self, v: T) -> Self
pub fn set_locked<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_validation_errors<T, V>(self, v: T) -> Self
pub fn set_validation_errors<T, V>(self, v: T) -> Self
Sets the value of validation_errors.
Example
let x = App::new().set_validation_errors(["a", "b", "c"]);Trait Implementations
impl StructuralPartialEq for App